#!/bin/ksh
#

########################################################
# set paths and files

MODULE="ErcGSM"
RELEASE="7.1.14.3.0"    
RP=$(echo $RELEASE|sed 's/\.//g')

SourceDir="${FLEXPM_HOME}/patches/${RELEASE}"
WorkDir=$SourceDir/workdir
TarFile=${SourceDir}/tarball/${MODULE}_${RP}_UI.tgz

### get ts
TS=`cat $SourceDir/Backup/.ts.txt`
BACKUP_DIR=$SourceDir/Backup/$TS

########################################################

# Check env settings
 echo "Checking environment....."

  if ! [[ -d ${FLEXPM_HOME} ]]; then
     echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
     exit;
  fi

  if ! [[ -d ${NE_BASE} ]]; then
     echo "Env variable NE_BASE must be set to appropriate dir before installation."
     exit;
  fi

  if [ -z ${DB_CONNECT} ]; then
     echo "Env variable DB_CONNECT must be set to approriate database connection values."
     exit 1;
  fi

  ###### module variable validation
  if ! [[ -d ${ErcGSM_HOME} ]]; then
     echo "Env variable ErcGSM_HOME must be set to appropriate dir before installation."
     exit;
  fi

    #######################################################
    # Installing module...
    #######################################################

    date +"+ Installing Patch $MODULE $RELEASE at %T, %D ..."

    echo "+ Backing up original files and installing new files..."
    cd $NE_BASE
    mkdir -p ${BACKUP_DIR}

    ${WorkDir}/untar.pl $SourceDir $TarFile $NE_BASE $BACKUP_DIR
    ret=$?

    if [ $ret != 0 ]; then
      echo "+++ Error in untar.pl"
      exit 2
    fi

    ###### module installation customerize here...

    touch parser.err
    chmod 777 parser.err

    echo "### running dict_update ###"
    cd $ErcGSM_HOME/peik
    make dict_update
    ret=$?

    if [ $ret != 0 ]; then
      echo "+++ Error in make dict_update"
      exit 2
    fi

    echo "### completed dict_update ###"

    echo
    echo "+ Updating GSM NBCell rollup package..."
    echo "@${ErcGSM_HOME}/vendor/Ericsson/GSM/summarize/erc_GSM_nbcell_rup2_cell_pkgb.sql" | sqlplus -s $DB_CONNECT
    ret=$?
    if [ $ret != 0 ]; then
	echo "+++ Failed to repackage GSM NBCell rollup"
    fi
    echo "+ Package updated."

    date +"+ $MODULE $RELEASE upgrade is completed at %T, %D"
    echo ""

